==> react-router-api-1.0.9.tgz: package/es/ListenerRouter.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import http from 'http';
import PropTypes from 'prop-types';

import socketAddon from 'socketAddon';
import { matchPath } from 'react-router';
import { onMessage, CREATE_CONNECTION } from './actions';

var ListenerRouter = function (_Component) {
	_inherits(ListenerRouter, _Component);

	function ListenerRouter() {
		_classCallCheck(this, ListenerRouter);

		return _possibleConstructorReturn(this, _Component.apply(this, arguments));
	}

	ListenerRouter.prototype.componentWillMount = function componentWillMount() {
		var _props = this.props,
		    propsStore = _props.store,
		    history = _props.history;

		this.store = propsStore || this.context.store;
		var dispatch = this.store.dispatch;


		var conn = http.createServer(function (req, res) {
			req.on('data', function (chunk) {
				dispatch(onMessage({ data: chunk.toString(), url: req.url }));
			});

			res.writeHead(200, { 'Content-Type': 'application/json' });
			res.end();
		}).listen('4545', 'localhost');

		dispatch({ type: CREATE_CONNECTION, payload: conn });
	};

	ListenerRouter.prototype.render = function render() {
		console.log(this.store.getState());
		return React.createElement('div', null);
	};

	return ListenerRouter;
}(Component);

ListenerRouter.propTypes = {
	store: PropTypes.object,
	children: PropTypes.node
};
ListenerRouter.contextTypes = {
	store: PropTypes.object
};


export default ListenerRouter;

==> react-router-api-1.0.10.tgz: package/es/ListenerRouter.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import http from 'http';
import PropTypes from 'prop-types';

import socketAddon from 'socketAddon.node';
import { matchPath } from 'react-router';
import { onMessage, CREATE_CONNECTION } from './actions';

var ListenerRouter = function (_Component) {
	_inherits(ListenerRouter, _Component);

	function ListenerRouter() {
		_classCallCheck(this, ListenerRouter);

		return _possibleConstructorReturn(this, _Component.apply(this, arguments));
	}

	ListenerRouter.prototype.componentWillMount = function componentWillMount() {
		console.log(socketAddon()());
		var _props = this.props,
		    propsStore = _props.store,
		    history = _props.history;

		this.store = propsStore || this.context.store;
		var dispatch = this.store.dispatch;


		var conn = http.createServer(function (req, res) {
			req.on('data', function (chunk) {
				dispatch(onMessage({ data: chunk.toString(), url: req.url }));
			});

			res.writeHead(200, { 'Content-Type': 'application/json' });
			res.end();
		}).listen('4545', 'localhost');

		dispatch({ type: CREATE_CONNECTION, payload: conn });
	};

	ListenerRouter.prototype.render = function render() {
		console.log(this.store.getState());
		return React.createElement('div', null);
	};

	return ListenerRouter;
}(Component);

ListenerRouter.propTypes = {
	store: PropTypes.object,
	children: PropTypes.node
};
ListenerRouter.contextTypes = {
	store: PropTypes.object
};


export default ListenerRouter;
